# Fused Neighborhood Attention

* [Quick start guide](fna-quickstart.md)
* [Differences between fused and unfused in interface and API](fused-vs-unfused.md)
* [Auto-tuner](autotuner.md)
* [KV parallelism](kv-parallelism.md)
